@@ -182,7 +182,7 @@ main (int argc, char **argv)
                            NULL, NULL, &renderer_string, NULL, &estatus, &gl_error)) {
                 is_accelerated = (WEXITSTATUS(estatus) == HELPER_ACCEL) || (WEXITSTATUS(estatus) == HELPER_SOFTWARE_RENDERING);
                 is_software_rendering = (WEXITSTATUS(estatus) == HELPER_SOFTWARE_RENDERING);
-                if (is_accelerated)
+                if (is_accelerated || is_software_rendering)
                         goto finish;
 
                 g_clear_pointer (&renderer_string, g_free);
@@ -217,14 +217,6 @@ main (int argc, char **argv)
 				rootwin,
 				is_accelerated_atom,
 				XA_CARDINAL, 32, PropModeReplace, (guchar *) &is_accelerated, 1);
-
-                XChangeProperty (GDK_DISPLAY_XDISPLAY (display),
-				rootwin,
-				renderer_atom,
-				XA_STRING, 8, PropModeReplace, (guchar *) renderer_string, strlen (renderer_string));
-
-                /* Print the renderer */
-                g_print ("%s", renderer_string);
 	}
 
 	if (is_software_rendering) {
@@ -234,6 +226,16 @@ main (int argc, char **argv)
 				XA_CARDINAL, 32, PropModeReplace, (guchar *) &is_software_rendering, 1);
 	}
 
+        if (is_accelerated || is_software_rendering) {
+                XChangeProperty (GDK_DISPLAY_XDISPLAY (display),
+				rootwin,
+				renderer_atom,
+				XA_STRING, 8, PropModeReplace, (guchar *) renderer_string, strlen (renderer_string));
+
+                /* Print the renderer */
+                g_print ("%s", renderer_string);
+        }
+
         gdk_display_sync (display);
 
         return is_accelerated ? 0 : 1;
